@@ -1,13 +1,12 @@
 from pathlib import Path
 
 import typer
-from recon.dataset import Dataset
 from recon.stats import get_ner_stats
 
 
 def main(data_file: Path):
     data = read_jsonl(data_file)
-    train_stats = get_ner_stats(data)
+    get_ner_stats(data)
     print(get_ner_stats(data, serialize=True))
 
 
