@@ -3,14 +3,12 @@ from pathlib import Path
 from typing import Any, Callable, Dict, List, Set, Union, cast
 
 import srsly
-from spacy.util import ensure_path
-from wasabi import Printer
-
-from .hashing import dataset_hash
-from .loaders import read_json, read_jsonl
-from .operations import registry
-from .store import ExampleStore
-from .types import (
+from recon.hashing import dataset_hash
+from recon.loaders import from_spacy, read_json, read_jsonl, to_spacy
+from recon.operations import registry
+from recon.stats import get_ner_stats
+from recon.store import ExampleStore
+from recon.types import (
     DatasetOperationsState,
     Example,
     OperationResult,
@@ -18,6 +16,8 @@ from .types import (
     OperationStatus,
     TransformationType,
 )
+from spacy.util import ensure_path
+from wasabi import Printer
 
 
 class Dataset:
@@ -91,6 +91,10 @@ class Dataset:
     def commit_hash(self) -> str:
         return cast(str, dataset_hash(self, as_int=False))
 
+    def __str__(self) -> str:
+        stats = get_ner_stats(self.data, serialize=True)
+        return f"Dataset: {self.name}\n" f"Stats: {stats}"
+
     def __hash__(self) -> int:
         return cast(int, dataset_hash(self))
 
@@ -317,6 +321,7 @@ class Dataset:
 
         for op_name, state in operations_to_run.items():
             op = registry.operations.get(op_name)
+
             self.apply_(op, *state.args, initial_state=state, **state.kwargs)  # type: ignore
 
         return self
@@ -360,7 +365,7 @@ class Dataset:
         Returns:
             Dataset: Initialized dataset with Prodigy data
         """
-        from recon.prodigy.util import from_prodigy
+        from recon.prodigy.utils import from_prodigy
 
         print(f"Loading data from prodigy datasets: {', '.join(prodigy_datasets)}")
         data = []
@@ -370,7 +375,16 @@ class Dataset:
         return self
 
     def to_prodigy(self, prodigy_dataset: str = None, overwrite: bool = True) -> str:
-        from recon.prodigy.util import to_prodigy
+        """Save examples to prodigy dataset
+
+        Args:
+            prodigy_dataset (str, optional): Prodigy dataset name to save to.
+            overwrite (bool, optional): Overwrite dataset name if it exists.
+
+        Returns:
+            str: Prodigy dataset name
+        """
+        from recon.prodigy.utils import to_prodigy
 
         if not prodigy_dataset:
             prodigy_dataset = f"{self.name}_{self.commit_hash}"
@@ -378,3 +392,27 @@ class Dataset:
         print(f"Saving dataset to prodigy dataset: {prodigy_dataset}")
         to_prodigy(self.data, prodigy_dataset, overwrite_dataset=overwrite)
         return prodigy_dataset
+
+    def from_spacy(self, path: Path) -> "Dataset":
+        """Load Dataset from a file in the .spacy format
+
+        Args:
+            path (Path): path to load from
+
+        Returns:
+            Dataset: Initialized dataset with Prodigy data
+        """
+        data = from_spacy(path)
+        self.data = list(data)
+        return self
+
+    def to_spacy(self, output_dir: Path) -> None:
+        """Save data to .spacy file
+
+        Saves file as {output_dir}/{self.name}.spacy
+
+        Args:
+            output_dir (Path): Output file path to save data to
+        """
+        output_dir = ensure_path(output_dir)
+        to_spacy(output_dir / (self.name + ".spacy"), self.data)
