@@ -3,8 +3,7 @@ from enum import Enum
 from typing import Any, Callable, Dict, List, NamedTuple, Optional, Tuple, cast
 
 from pydantic import BaseModel, Extra, root_validator
-
-from .hashing import span_hash, token_hash, tokenized_example_hash
+from recon.hashing import span_hash, token_hash, tokenized_example_hash
 
 
 class Span(BaseModel):
@@ -291,3 +290,11 @@ class Correction(BaseModel):
     annotation: str
     from_labels: List[str]
     to_label: Optional[str] = None
+
+
+class Scores(BaseModel):
+    ents_p: float
+    ents_r: float
+    ents_f: float
+    ents_per_type: Dict[str, Any]
+    speed: float
